@@ -12,22 +12,14 @@ author "Caleb Anderson"
 version "0.2"
 description "This plugin detects RSS feeds and extracts the RSS feed source."
 
-# Examples #
-examples %w|
-itsecuritysolutions.org
-morningstarsecurity.com
-ha.ckers.org
-www.kiwicon.org
-adrianlamologs.blogspot.com
-www.wired.com
-|
+
 
 # Matches #
 matches [
 
 # Extract RSS feed source
-{ :version=>/<link[^>]*href[\s]*=[\s]*["']([^'^"^\s^>]+)[^>]*type[\s]*=[\s]*["']application\/rss\+xml["'][^>]*/i },
-{ :version=>/<link[^>]*type[\s]*=[\s]*["']application\/rss\+xml["'][^>]*href[\s]*=[\s]*["']([^'^"^\s^>]+)[^>]*/i },
+{ :string=>/<link[^>]*href[\s]*=[\s]*["']([^'^"^\s^>]+)[^>]*type[\s]*=[\s]*["']application\/rss\+xml["']/i },
+{ :string=>/<link[^>]*type[\s]*=[\s]*["']application\/rss\+xml["'][^>]*href[\s]*=[\s]*["']([^'^"^\s^>]+)/i },
 
 ]
 
