@@ -9,10 +9,15 @@ author "Brendan Coles <bcoles@gmail.com>" # 2010-09-17
 version "0.1"
 description "AContent  is an open source learning content authoring system and respository used to create interoperable, accessible, adaptive Web-based learning content. - homepage: http://www.atutor.ca/acontent/"
 
-# 1 result for intitle:"AContent: Learning Content Repository:" @ 2010-09-17
-examples %w|
-www.atutor.ca/acontent/demo.php
-|
+# Google results as at 2010-09-17 #
+# 1 for intitle:"AContent: Learning Content Repository:"
+
+# Dorks #
+dorks [
+'intitle:"AContent: Learning Content Repository:"'
+]
+
+
 
 matches [
 
@@ -22,6 +27,9 @@ matches [
 # Login page
 { :text=>'<dt><span class="required" title="Required Field">*</span><label for="login">Login Name or Email</label></dt>' },
 
+# Default Favicon
+{ :md5=>"28c34462a074c5311492759435549468", :url=>"/favicon.ico" },
+
 ]
 
 
