@@ -9,11 +9,15 @@ author "Brendan Coles <bcoles@gmail.com>" # 2010-09-17
 version "0.1"
 description "ATutor is a free Open Source Web-based elearning environment designed with accessibility and adaptability in mind. - homepage: http://www.atutor.ca/"
 
-# 34 results for intitle:"ATutor: Learning Management System:" @ 2010-09-17
-examples %w|
-demo.opensourcecms.com/atutor/login.php
-dev.atutor.ca/atutor/demo.php
-|
+# Google results as at 2010-09-17 #
+# 34 for intitle:"ATutor: Learning Management System:"
+
+# Dorks #
+dorks [
+'intitle:"ATutor: Learning Management System:"'
+]
+
+
 
 matches [
 
@@ -26,6 +30,10 @@ matches [
 # Default logo HTML
 { :text=>'<a href="http://www.atutor.ca/"><img src="/atutor/images/AT_Logo_1_sm.png"  alt="ATutor Logo" style="border:none;" /></a>' },
 
+# Default Favicon
+{ :md5=>"5b816961f19da96ed5a2bf15e79093cb", :url=>"/favicon.ico" },
+
+
 ]
 
 
