@@ -9,20 +9,11 @@ author "Brendan Coles <bcoles@gmail.com>" # 2010-10-30
 version "0.1"
 description "AirOS is an intuitive, versatile, highly developed Ubiquiti firmware technology that resides on Ubiquiti Station products. It is exceptionally intuitive and was designed to require no training to operate. Behind the user interface is a powerful firmware architecture which enables hi-performance outdoor multipoint networking.  - homepage: http://www.ubnt.com/airos"
 
-# 8411 ShodanHQ results for "Set-Cookie:" "AIROS_SESSIONID" Path= Version=
-# 8411 ShodanHQ results for "cookiechecker uri="
-examples %w|
-109.73.178.41
-79.110.115.131
-88.148.20.201
-91.202.136.212
-82.177.204.114
-208.65.187.90
-209.150.15.65
-62.122.121.201
-190.221.44.70
-78.28.122.244
-|
+# ShodanHQ results as at 2010-10-30 #
+# 8,411 for "Set-Cookie:" "AIROS_SESSIONID" Path= Version=
+# 8,411 for "cookiechecker uri="
+
+
 
 matches [
 
@@ -36,10 +27,10 @@ def passive
 	m=[]
 
 	# Cookie
-	m << { :name=>"AIROS_SESSIONID Cookie" } if @meta["set-cookie"] =~ /AIROS_SESSIONID=[a-z0-9]{32}; Path=\/; Version=([\d\.]+)/
+	m << { :name=>"AIROS_SESSIONID Cookie" } if @headers["set-cookie"] =~ /AIROS_SESSIONID=[a-z0-9]{32}; Path=\/; Version=([\d\.]+)/
 
 	# Location: /cookiechecker?uri=/
-	m << { :name=>"Location HTTP Header", :status=>301 } if @meta["location"] =~ /\/cookiechecker\?uri=\//
+	m << { :name=>"Location HTTP Header", :status=>301 } if @headers["location"] =~ /\/cookiechecker\?uri=\//
 
 	m
 
