@@ -12,14 +12,12 @@ description "Atomic CMS is a powerful and free open source ASP.NET CMS (content
 # Google results as at 2011-03-04 #
 # 24 for "Powered by AtomicCms"
 
-# Examples #
-examples %w|
-atomiccms.com
-alexandershapovalov.com
-cookbrownrice.com
-www.bobotics319.com
-dev.conesandsconesicecreamery.com
-|
+# Dorks #
+dorks [
+'"Powered by AtomicCms"'
+]
+
+
 
 # Matches #
 matches [
