@@ -12,15 +12,12 @@ description "Bart's CMS is a website Content Management System that is build wit
 # Google results as at 2011-03-03 #
 # 93 for "powered by Bart's CMS"
 
-# Examples #
-examples %w|
-trinityhome.org
-urlfriendly.trinityhome.org
-www.djansa.be
-www.3care.be/ImageGallery/
-www.strikkies.be
-cms.ccsdemo.nl/Users/
-|
+# Dorks #
+dorks [
+'"powered by Bart\'s CMS"'
+]
+
+
 
 # Matches #
 matches [
