@@ -5,7 +5,7 @@
 # http://www.morningstarsecurity.com/research/whatweb
 ##
 # Version 0.2 # 2011-03-02 #
-# Removed redundant capitalized @meta["Server"] match
+# Removed redundant capitalized @headers["Server"] match
 ##
 # Version 0.3 2011-03-16 by Andrew Horton
 # Added cisco model detection
@@ -18,38 +18,23 @@ description "Cisco IOS (originally Internetwork Operating System) is the softwar
 # ShodanHQ results as at 2010-10-26 #
 # 284,567 for "server: cisco-IOS"
 
-# Examples #
-examples %w|
-96.61.214.8
-122.227.189.246
-199.2.209.61
-202.6.154.2
-216.244.169.38
-199.216.192.128
-91.206.162.13
-95.14.189.62
-65.61.46.1
-195.133.224.193
-|
 
+
+# Matches #
 matches [
+
+# Model Detection
 { :model=>/\ssdmconfig-([^\.]+).cfg/}, 
 { :model=>/\sc(\d+)(nm)?[^\-]*-\S+-mz\S+\.bin/}, 
+
+# Directory
 { :string=>"Dir",     :regexp=>/<input type="hidden" name="DIRINFO" value="\s+Directory of archive:\// },
-{ :string=>"DirFail", :regexp=>/<input type="hidden" name="DIRINFO" value="\s*(Command authorization failed|% Authorization failed)/ }
+{ :string=>"DirFail", :regexp=>/<input type="hidden" name="DIRINFO" value="\s*(Command authorization failed|% Authorization failed)/ },
+
+# HTTP Server Header
+{ :search=>"headers[server]", :regexp=>/^cisco-IOS/ },
+
 ]
 
-# Passive #
-def passive
-	m=[]
-
-	# HTTP Server Header
-	m << { :name=>"HTTP Server Header" } if @meta["server"].to_s =~ /^[\s]*cisco-IOS/
-
-	# Return passive matches
-	m
-
-end
-
 end
 
