@@ -12,19 +12,12 @@ description "Contentteller - A powerful Content Management System with 20 module
 # Google results as at 2011-03-03 #
 # 39 for "powered by Contentteller"
 
-# Examples #
-examples %w|
-www.contentteller.com
-www.power-systems.org
-www.compatdb.org
-livonet.com
-doctorwatson.info/sussex/
-onondagalake.info
-www.linuxcompatible.org
-www.warp2search.net
-www.ntcompatible.com
-www.pedaltothemetal.com
-|
+# Dorks #
+dorks [
+'"powered by Contentteller"'
+]
+
+
 
 # Matches #
 matches [
