@@ -16,21 +16,13 @@ description "CubeCart is an out of the box ecommerce shopping cart software solu
 # 492 results for intitle:"powered by cubecart"
 # 643 results for "powered by cubecart"
 
-# Examples #
-examples %w|
-demo.cubecart.com/cc3/
-americankaiju.kaijuphile.com/store/index.php
-myjapantshirt.com
-downloadfitnessmusic.com
-prestonsbooks.com
-sugarsugarbags.com/shop/index.php
-www.bijouxandzoe.com
-www.claudiasbaskets.com
-www.node3-records.com/shop/
-www.thecdguyz.com
-www.trustmagic.com.au/index.php
-www.yanelis3d.net/store/
-|
+# Dorks #
+dorks [
+'intitle:"powered by cubecart"',
+'"powered by cubecart"'
+]
+
+
 
 # Matches #
 matches [
