@@ -12,12 +12,12 @@ description "Daffodil CRM is a software that enables seamless coordination betwe
 # Google results as at 2011-04-02 #
 # 3 for "Daffodil" inurl:app=forgot_passwd
 
-# Examples #
-examples %w|
-www.dis.edu.bd/vus/
-erp.daffodilvarsity.edu.bd/vus/
-203.190.10.145/green/
-|
+# Dorks #
+dorks [
+'"Daffodil" inurl:app=forgot_passwd'
+]
+
+
 
 # Matches #
 matches [
