@@ -9,22 +9,15 @@ author "Brendan Coles <bcoles@gmail.com>" # 2010-10-11
 version "0.1"
 description "The donations cloud is something like a tag cloud, only that it displays . donations. The more a person donates, the larger the link to his/her website will be. - homepage: http://www.zirona.com/software/wordpress-donations-cloud/"
 
-# 58 results for "powered by Donations Cloud" @ 2010-10-11
-examples %w|
-www.zirona.com
-lucrenainternet.com
-myworldtour.net
-robeverest.com
-superwahmmy.com
-thecelebritydb.com
-www.attackvector.org
-www.homepagerelated.com
-www.ideiasparanegocios.com
-www.padgamers.de
-www.pcdicasuteis.com
-www.ps3attitude.com
-www.webmasterbulletin.net
-|
+# Google results as at 2010-10-11 #
+# 58 for "powered by Donations Cloud"
+
+# Dorks #
+dorks [
+'"powered by Donations Cloud"'
+]
+
+
 
 matches [
 
