@@ -12,14 +12,12 @@ description "Entrans is an online translation tool. The tool can be used by the
 # Google results as at 2011-02-27 #
 # 6 for "View All Strings" "The tool can be used by the online community"
 
-# Examples #
-examples %w|
-entrans.sourceforge.net/demo/
-translate.gelatocms.com/main.php
-translate.sbbic.org
-community.topracers.net/main.php
-translate.wp-persian.com/main.php
-|
+# Dorks #
+dorks [
+'"View All Strings" "The tool can be used by the online community"'
+]
+
+
 
 # Matches #
 matches [
