@@ -9,25 +9,15 @@ author "Brendan Coles <bcoles@gmail.com>" # 2010-10-15
 version "0.1"
 description "Out of thebox, Exponent Content Management System touts a feature-rich assortment of tools to assist you in your online content management. Requirements: Apache 1.3, 2.0, or 2.2, PHP 4.4 or later, PHP GD Image Library extension, MySQL 4.1.22 or later - homepage: http://www.exponentcms.org/index.php?section=116"
 
-# 94 results for "powered by Exponent CMS" @ 2010-10-15
-examples %w|
-beyondthebeatenpath.com
-fortwayneworkingdog.org
-noiraonline.org
-www.3riversworkingdog.org
-www.abinfo.com.br
-www.chapmanqualityroofing.co.uk
-www.circleofbusiness.org
-www.consult-avatar.com
-www.danjim.com.au
-www.englishdrama-trier.de
-www.heritagescience.ac.uk
-www.metalmar.net/exp/
-www.path3.com
-www.rcfrn.org/cms/
-www.ridgeworks.ca
-www.riia.ro
-|
+# Google results as at 2010-10-15 #
+# 94 for "powered by Exponent CMS"
+
+# Dorks #
+dorks [
+'"powered by Exponent CMS"'
+]
+
+
 
 matches [
 
