@@ -12,14 +12,12 @@ description "Hot Banana is an award-winning, easy-to-use Web Content Management
 # Google results as at 2011-03-03 #
 # 42 for "powered by hot banana"
 
-# Examples #
-examples %w|
-www.visitgrey.ca
-www.medivalu.com
-www.sterlingaccount.com
-www.mcat-gta.ca/members/
-seegrey.com
-|
+# Dorks #
+dorks [
+'"powered by hot banana"'
+]
+
+
 
 # Matches #
 matches [
