@@ -12,10 +12,7 @@ description "IPMATE router [Japanese] - http://www.ntt-east.co.jp/"
 # ShodanHQ results as at 2011-03-07 #
 # 1 for IPMATE
 
-# Examples #
-examples %w|
-210.232.156.129
-|
+
 
 # Matches #
 matches [
@@ -33,7 +30,7 @@ def passive
 	m=[]
 
 	# HTTP Server Header
-	m << { :model=>"1300RD" } if @meta["server"] =~ /^IPMATE 1300RD$/
+	m << { :model=>"1300RD" } if @headers["server"] =~ /^IPMATE 1300RD$/
 
 	# Return passive matches
 	m
