@@ -13,10 +13,7 @@ description "Linksys Print Server - Print servers connect printers directly to t
 # 1,142 for PRINT_SERVER WEB
 # 1,142 for PRINT_SERVER WEB 1.0
 
-# Examples #
-examples %w|
-173.12.38.72
-|
+
 
 # Matches #
 matches [
@@ -34,7 +31,7 @@ def passive
 	m=[]
 
 	# Server: PRINT_SERVER WEB # Also used by other printer servers
-	m << { :certainty=>25, :version=>@meta["server"].scan(/^PRINT_SERVER WEB ([\d\.]+)$/) } if @meta["server"] =~ /^PRINT_SERVER WEB ([\d\.]+)$/
+	m << { :certainty=>25, :version=>@headers["server"].scan(/^PRINT_SERVER WEB ([\d\.]+)$/) } if @headers["server"] =~ /^PRINT_SERVER WEB ([\d\.]+)$/
 
 	# Return passive matches
 	m
