@@ -15,15 +15,12 @@ description "PHP contact form - homepage: http://www.h-fj.com/blog/mtplgdoc/"
 # Google results as at 2010-09-18 #
 # 24 for "powered by MailForm"
 
-# Examples #
-examples %w|
-www.mt-j.info/contact.html
-ono-eye.jpmd.org/mailform.html
-soramame.com.au/en/mail-form.php
-www.another-here-i-am.com/mailform.php
-www.clover8.com/mailform.html
-www.jatts.jp/admissionform.html
-|
+# Dorks #
+dorks [
+'"powered by MailForm"'
+]
+
+
 
 # Matches #
 matches [
