@@ -12,11 +12,7 @@ description "Fujitsu NetShelter/VPN [Japanese] - an IPSec-compliant VPN device w
 # ShodanHQ results as at 2011-03-07 #
 # 2 for NetShelter
 
-# Examples #
-examples %w|
-211.10.78.132
-210.188.186.211
-|
+
 
 # Matches #
 matches [
@@ -27,18 +23,11 @@ matches [
 # Logo
 { :url=>"/images/sb_logo.gif", :md5=>"ffacfeae7e203bd8de5c9da889d217ec" },
 
+# HTTP Server Header
+{ :search=>"headers[server]", :regexp=>/^NetShelter\/VPN$/ },
+
 ]
 
-# Passive #
-def passive
-	m=[]
-
-	# HTTP Server Header
-	m << { :name=>"HTTP Server Header" } if @meta["server"] =~ /^NetShelter\/VPN$/
-	# Return passive matches
-	m
-end
-
 end
 
 
