@@ -12,15 +12,7 @@ description "Fujitsu NetVehicle router [Japanese] - Homepage: http://fenics.fuji
 # ShodanHQ results as at 2011-03-08 #
 # 9 for NetVehicle
 
-# Examples #
-examples %w|
-211.5.204.252
-202.221.162.90
-211.120.188.214
-210.136.6.97
-211.124.158.177
-61.215.160.126
-|
+
 
 # Matches #
 matches [
@@ -38,7 +30,7 @@ def passive
 	m=[]
 
 	# Model Detection # HTTP Server Header
-	m << { :model=>@meta["server"].scan(/^NetVehicle-([A-Z\d]{1,3})/) } if @meta["server"] =~ /^NetVehicle-([A-Z\d]{1,3})/
+	m << { :model=>@headers["server"].scan(/^NetVehicle-([A-Z\d]{1,3})/) } if @headers["server"] =~ /^NetVehicle-([A-Z\d]{1,3})/
 
 	# Return passive matches
 	m
