@@ -12,18 +12,12 @@ description "Written in PHP and powered by MySQL, OvBB is a light-weight and fas
 # Google results for 2010-09-26 #
 # 34 for "powered by OvBB"
 
-# Examples #
-examples %w|
-community.namforum.com
-averonstudio.zoomcities.com/forums/
-ciprodiscussion.com/forum/
-azulblues.com/message/upload/
-www.auditdatabase.com/Forum/
-www.theenglishlab.net/forum/
-www.rv-ideas.com
-www.divineideas.org/message/upload/
-www.aggressiveprostatecancer.com/blog/forum/
-|
+# Dorks #
+dorks [
+'"powered by OvBB"'
+]
+
+
 
 # Matches #
 matches [
