@@ -12,15 +12,12 @@ description "PTCPay is a sofware development company that develops and supports
 # Google results as at 2011-02-27 #
 # 7 for "Login into your admin panel" "PTCPay.Com" inurl:"admin"
 
-# Examples #
-examples %w|
-ptcpay.com/gen4demo/admin/
-www.alertpay2pk.com/admin/
-www.klikasik.com/admin/
-host-ptc.com/demo/admin/
-cgrolandia.com.br/marc/gen4/admin/
-simplexer.nl/admin/
-|
+# Dorks #
+dorks [
+'"Login into your admin panel" "PTCPay.Com" inurl:"admin"'
+]
+
+
 
 # Matches #
 matches [
