@@ -10,19 +10,13 @@ version "0.1"
 description "Pixelpost is an open-source, standards-compliant, multi-lingual, fully extensible photoblog application for the web. Requirements: PHP 4.3 or greater (w/ GD-lib) and MySQL 3.23.58 or greater - homepage: http://www.pixelpost.org/"
 
 # 382 results for "powered by pixelpost" @ 2010-09-18
-examples %w|
-blog.benjaminvenancie.com
-brendannewell.com
-www.choobnam.com
-www.djve.com
-kasperchristiansen.com
-photos.livingdot.com
-www.chantefleur.net
-www.eighteenfiftysix.com/pixelpost/
-www.okebaja.nl
-www.skinnybuzzard.com
-www.sodapopthesis.com
-|
+
+# Dorks #
+dorks [
+'"powered by pixelpost"'
+]
+
+
 
 matches [
 
