@@ -10,11 +10,13 @@ version "0.1"
 description "SazCart is a simple & powerful shopping cart script. With SazCart you can quickly and easily setup an online store. Then customize it to exactly how you want it to work & look. - homepage: http://www.sazcart.com/"
 
 # 24 results for "powered by SazCart" @ 2010-08-22
-examples %w|
-www.sazcart.com/demo/
-expeditionaddicts.com/store/
-www.redpetalcards.com/store/
-|
+
+# Dorks #
+dorks [
+'"powered by SazCart"'
+]
+
+
 
 matches [
 
