@@ -12,15 +12,12 @@ description "Simple Forum PHP is a script that is very easy to install and admin
 # Google results as at 2011-02-26 #
 # 4 for intitle:"Simple Forum PHP script - Administration"
 
-# Examples #
-examples %w|
-www.simpleforumphp.com/forum/admin.php
-www.simpleforumphp.com/forum/forum.php
-12letters.com/alpha/forum/admin.php
-12letters.com/alpha/forum/forum.php
-ghanaswatchdog.com/forum/admin.php
-https://www.laparoscopyhospital.com/forum/admin.php
-|
+# Dorks #
+dorks [
+'intitle:"Simple Forum PHP script - Administration"'
+]
+
+
 
 # Matches #
 matches [
