@@ -15,14 +15,12 @@ description "Deploy your own professional knowledge base or knowledge repository
 # Google results as at 2010-11-08 #
 # 15 for "Powered by SocketKB version" -intext
 
-# Examples #
-examples %w|
-socketkb.com/site/home/demo_coolblue.php
-socketkb.com/site/home/demo_default.php
-kb.c-comsat.com
-kb2.c-comsat.com/home/
-www.classiclandscapes.com/socketkb/
-|
+# Dorks #
+dorks [
+'"Powered by SocketKB version" -intext'
+]
+
+
 
 # Matches #
 matches [
