@@ -15,28 +15,17 @@ description "Squid is a caching proxy for the Web supporting HTTP, HTTPS, FTP, a
 # ShodanHQ results as at 2010-10-25 #
 # 115,253 for "Server: squid"
 
-# Examples #
-examples %w|
-184.82.40.169
-200.112.202.56
-196.22.14.203
-195.71.11.68
-109.169.38.95
-203.56.14.207
-85.124.85.114
-109.108.128.157
-121.120.79.43
-|
+
 
 # Passive #
 def passive
 	m=[]
 
 	# X-Squid-Error # Also used by iPrism, CachePower, and MecGuard 
-	m << { :name=>"x-squid-error", :certainty=>25 } unless @meta["x-squid-error"].nil?
+	m << { :name=>"x-squid-error", :certainty=>25 } unless @headers["x-squid-error"].nil?
 
 	# Server
-	m << { :version=>@meta["server"].to_s.scan(/[\s]*Squid\/([^\r^\n]+)/i) } if @meta["server"] =~ /[\s]*Squid\/([^\r^\n]+)/i
+	m << { :version=>@headers["server"].to_s.scan(/[\s]*Squid\/([^\r^\n]+)/i).flatten } if @headers["server"] =~ /[\s]*Squid\/([^\r^\n]+)/i
 
 	# Return passive results
 	m
