@@ -10,12 +10,13 @@ version "0.1"
 description "homepage: http://www.tcms-sep.com"
 
 # 26 results for "powered by TCMS" @ 2010-08-28
-examples %w|
-image.tanzarine.net
-www.oberhessen.de
-www.weber-wireless.com
-www.verein-oberhessen.de
-|
+
+# Dorks #
+dorks [
+'"powered by TCMS"'
+]
+
+
 
 matches [
 
@@ -27,12 +28,12 @@ def passive
         m=[]
 
 	# TCMS_SESS_ID cookie
-	m << {:name=>"TCMS_SESS_ID Cookie" } if @meta["set-cookie"] =~ /TCMS_SESS_ID=/
+	m << {:name=>"TCMS_SESS_ID Cookie" } if @headers["set-cookie"] =~ /TCMS_SESS_ID=/
 
 	# 2.0+ powered by text
         if @body =~ /				<a style="color:#999;" href="http:\/\/www.arsmedia-nidda.de">arsmedia<\/a>/
 		if @body =~ /powered by TCMS v[0-9\.]+ &copy; [0-9]{4} by/
-	                version=@body.scan(/powered by TCMS v([\d\.]+) &copy; [0-9]{4} by/).to_s
+	                version=@body.scan(/powered by TCMS v([\d\.]+) &copy; [0-9]{4} by/).flatten
         	        m << {:version=>version}
 		end
         end
