@@ -13,11 +13,7 @@ description "TRENDnet Print Server - Print servers connect printers directly to
 # 1,142 for PRINT_SERVER WEB
 # 1,142 for PRINT_SERVER WEB 1.0
 
-# Examples #
-examples %w|
-72.64.111.243
-148.204.181.87
-|
+
 
 # Matches #
 matches [
@@ -35,7 +31,7 @@ def passive
 	m=[]
 
 	# Server: PRINT_SERVER WEB # Also used by other printer servers
-	m << { :certainty=>25, :version=>@meta["server"].scan(/^PRINT_SERVER WEB ([\d\.]+)$/) } if @meta["server"] =~ /^PRINT_SERVER WEB ([\d\.]+)$/
+	m << { :certainty=>25, :version=>@headers["server"].scan(/^PRINT_SERVER WEB ([\d\.]+)$/) } if @headers["server"] =~ /^PRINT_SERVER WEB ([\d\.]+)$/
 
 	# Return passive matches
 	m
