@@ -11,13 +11,7 @@ description "VTS Server"
 
 # 123 ShodanHQ results for Server: VTS
 # 103 ShodanHQ results for Set-Cookie: VTS=
-examples %w|
-71.42.172.182
-99.167.253.150
-142.176.153.126
-166.139.45.60
-216.171.226.110
-|
+
 
 matches [
 
@@ -31,10 +25,10 @@ def passive
 	m=[]
 
 	# Version Detection # HTTP Server Header
-	m << { :version=>@meta["server"].scan(/VTS ([\d\.]+)/) } if @meta["server"] =~ /VTS ([\d\.]+)/
+	m << { :version=>@headers["server"].scan(/VTS ([\d\.]+)/) } if @headers["server"] =~ /VTS ([\d\.]+)/
 
 	# Version Detection # HTTP Set-Cookie Header
-	m << { :version=>@meta["set-cookie"].scan(/^VTS=([\d\.]+);Version=1;Path=\//) } if @meta["set-cookie"] =~ /^VTS=([\d\.]+);Version=1;Path=\//
+	m << { :version=>@headers["set-cookie"].scan(/^VTS=([\d\.]+);Version=1;Path=\//) } if @headers["set-cookie"] =~ /^VTS=([\d\.]+);Version=1;Path=\//
 
 	m
 
