@@ -10,22 +10,13 @@ version "0.1"
 description "Blog - homepage: http://www.zomp.nl/zomplog/index.php"
 
 # 72 results for "powered by Zomplog" -Vulnerability -exploit @ 2010-09-18
-examples %w|
-annegret.intensiverleben.at/blogme/
-annegret.intensiverleben.at/blogme/login.php
-demo.opensourcecms.com/zomplog/index.php
-demo.opensourcecms.com/zomplog/login.php
-kat.griesstopf.de
-kat.griesstopf.de/login.php
-wilkie.rcxp.ca/msp23/
-wilkie.rcxp.ca/msp23/login.php
-www.ajetotechniek.nl/cms/
-www.ajetotechniek.nl/cms/login.php
-www.catherinefreemanfoundation.com/blog/
-www.catherinefreemanfoundation.com/blog/login.php
-www.oregonbodybuilding.com/blog/index.php
-www.oregonbodybuilding.com/blog/login.php
-|
+
+# Dorks #
+dorks [
+'"powered by Zomplog" -Vulnerability -exploit'
+]
+
+
 
 matches [
 
