@@ -9,20 +9,15 @@ author "Brendan Coles <bcoles@gmail.com>" # 2010-10-12
 version "0.1"
 description "homepage: http://www.zylone.com/"
 
-# 50 results for "powered by Zylone IT" -Vulnerability @ 2010-10-12
-examples %w|
-agape-gean.com.sg
-demo3.zylone.com/genetic-cms/
-www.aeimage.com.sg
-www.avitar.com.sg
-www.digiesl.com
-www.digisound.com.sg
-www.hof.com.my
-www.jessicapatterson.com/index.php
-www.millionblogshops.com/index_.php
-www.orange-lantern.com
-www.tae.com.sg
-|
+# Google results as at 2010-10-12 $
+# 50 for "powered by Zylone IT" -Vulnerability
+
+# Dorks #
+dorks [
+'"powered by Zylone IT" -Vulnerability'
+]
+
+
 
 matches [
 
