@@ -14,13 +14,12 @@ description "Basilic is a bibliography server for research laboratories. It auto
 
 # 14 results for "powered by basilic" @ 2010-08-14
 
-# Examples #
-examples %w|
-www.lifl.fr/GRAPHIX/publications.php
-secure.ntsg.umt.edu/publications/
-www.liaad.up.pt/pub/
-www.inis.iarc.uaf.edu/publications/
-|
+# Dorks #
+dorks [
+'"powered by basilic"'
+]
+
+
 
 # Matches #
 matches [
