@@ -12,17 +12,12 @@ description "Bitweaver is a free and open source web application framework and c
 # Google results as at 2011-02-24 #
 # 151 for "powered by bitweaver"
 
-# Examples #
-examples %w|
-www.bitweaver.org
-greenwaylabs.org
-www.netpanzer.org
-voip-info.linuxsys.com/wiki/
-theclones.net/wiki/
-medw.co.uk
-www.ausfirst.com/bitweaver/
-oaktop.com/wiki/
-|
+# Dorks #
+dorks [
+'"powered by bitweaver"'
+]
+
+
 
 # Matches #
 matches [
