@@ -14,18 +14,12 @@ description "Campsite is a multilingual content management system (CMS) for news
 
 # 28 results for "powered by campsite" @ 2010-08-15
 
-# Examples #
-examples %w|
-campsite-demo.sourcefabric.org
-www.mdlf.org
-post.oursammie.net
-birn.eu.com
-www.bim.ba
-blint.org
-jeromehomenews.com
-collegian.lasalle.edu
-www.studio88.ba
-|
+# Dorks #
+dorks [
+'"powered by campsite"'
+]
+
+
 
 # Matches #
 matches [
