@@ -15,18 +15,12 @@ description "Custom CMS Gaming is a Content Management System geared towards all
 # Google results as at 2010-09-03 #
 # 165 for "powered by CCMS"
 
-# Examples #
-examples %w|
-gameworldcheats.com
-www.tolvuleikir.is
-www.blpnetwork.com/index.php
-nintygamer.co.za/index.php
-ihrgamingnet.com
-www.playstation-3.co.za
-moddit.net
-gcult.the-chosen.ch
-www.gamezbox.co.uk/index.php
-|
+# Dorks #
+dorks [
+'"powered by CCMS"'
+]
+
+
 
 # Matches #
 matches [
