@@ -10,12 +10,13 @@ version "0.1"
 description "DT Centrepiece is a free open-source content management system (CMS) for commercial or personal use. - homepage: www.dt.net.nz/centrepiece/"
 
 # 14 results for "powered by DT Centrepiece" @ 2010-08-06
-examples %w|
-www.dt.net.nz
-www.talktracy.com
-www.hortidomus.com
-tattoo.gl/c4/
-|
+
+# Dorks #
+dorks [
+'"powered by DT Centrepiece"'
+]
+
+
 
 matches [
 
