@@ -14,16 +14,12 @@ description "eSyndiCat is a professional, affordable directory software solution
 
 # 8 results for "Powered by eSyndiCat Web Directory" @ 2010-08-08
 
-# Examples #
-examples %w|
-www.esyndicat.com/demo/
-www.esyndicat.com/demo/admin/
-omega.esyndicat.com
-omega.esyndicat.com/admin/
-www.pornblogsdir.com
-www.spiritueleforum.nl/links/
-www.seksdatabase.nl
-|
+# Dorks #
+dorks [
+'"Powered by eSyndiCat Web Directory"'
+]
+
+
 
 # Matches #
 matches [
