@@ -13,26 +13,13 @@ version "0.2"
 description "F3Site is a lightweight CMS written in XHTML 1.0 Strict, CSS and PHP 5. It lets you create multilingual websites without necessity of separate installation for each language. - homepage: http://compmaster.prv.pl"
 
 # 64 results for "powered by F3Site" -exploit -dork @ 2010-10-20
-examples %w|
-www.gon.ugu.pl
-www.smolinscy.pl
-www.nowetaniej.pl
-pzhgp-krotoszyn.pl
-kolarstwo-zachodniopomorskie.org
-www.reprotechnika.pl
-www.stspl.eu
-www.hucisko.pl
-zarabianiepieniedzy.net
-www.e-edytor.com/pl2/
-gimnazjum7kielce.pl
-www.pkenha.yoyo.pl
-darklife.kilu.de
-juveblog.pl
-www.rekodzielo.talaska.pl
-p98fongo.ugu.pl
-www.szczakowianka.jaworzno.pl
-erotyka.darmowe-porno.sex.pl
-|
+
+# Dorks #
+dorks [
+'"powered by F3Site" -exploit -dork'
+]
+
+
 
 matches [
 
