@@ -10,13 +10,13 @@ version "0.1"
 description "FestOS is web-based arts-n-crafts festival management software - homepage: http://festengine.org/"
 
 # 5 results for +"powered by FestOS" @ 2010-07-18
-examples %w|
-skypanther.com/festos.php
-demo.festengine.org
-www.fairportcanaldays.com
-www.trilogynewberg.com
-www.parkavesummerartfest.com/parkavefest/
-|
+
+# Dorks #
+dorks [
+'"powered by FestOS"'
+]
+
+
 
 matches [
 
