@@ -10,30 +10,13 @@ version "0.1"
 description "iRealty is an advanced flexible php real estate software and CMS with open source code. - homepage: http://www.irealtysoft.com/"
 
 # 52 results for "powered by iRealty" @ 2010-08-08
-examples %w|
-informasikos.com
-www.sakanonline.com
-www.stefanouproperties.com
-fortmyersvacationrentalsfl.com
-homesperson2person.com
-www.jameendalal.com
-www.bulgaria-apartments.org
-www.mrrent-paphos.net
-www.searchlosangeleshomes.com
-www.hottarget.de
-www.elarabia-estate.com
-www.exchangeproperties.co.uk
-www.craigrooms.com
-www.propertyforsale.gr
-inmomenorca.es
-www.propertymarketservice.co.uk
-www.collegebyowner.com
-www.panama.bz
-www.yuva24.com
-www.viveyanda.com
-home2cell.com
-www.dlm.hr
-|
+
+# Dorks #
+dorks [
+'"powered by iRealty"'
+]
+
+
 
 matches [
 
@@ -51,7 +34,7 @@ matches [
 def passive
         m=[]
 
-	m << { :name=>"iRealty PHPSESSID%28_%29 cookie" } if @meta["set-cookie"] =~ /^PHPSESSID%28_%29=[a-z0-9]{32}/
+	m << { :name=>"iRealty PHPSESSID%28_%29 cookie" } if @headers["set-cookie"] =~ /^PHPSESSID%28_%29=[a-z0-9]{32}/
 
         m
 
