@@ -10,21 +10,13 @@ version "0.1"
 description "iScripts CyberMatch is an open source online dating software with features like background check ,chat alerts, integrated payment system etc. - homepage: http://www.iscripts.com/cybermatch/"
 
 # 26 results for "powered by iScripts CyberMatch" "A premium product from iScripts.com" @ 2010-07-11
-examples %w|
-ebonyalt.com
-thecybermatch.com
-datingboomer.com
-matchwithin.com
-significantotherz.com
-forlatebloomers.com/date/
-keemera.com
-georgiauptownsingles.com
-www.7artsdating.co.uk
-www.happypartners.com
-www.loverslanedating.com
-www.gamerloveconnections.com
-www.singlesmeetsafe.com
-|
+
+# Dorks #
+dorks [
+'"powered by iScripts CyberMatch" "A premium product from iScripts.com"'
+]
+
+
 
 matches [
 
