@@ -10,13 +10,13 @@ version "0.1"
 description "iScripts ReserveLogic offers an online web based reservation system for the hospitality industry for service providers. - homepage: http://www.iscripts.com/reservelogic/"
 
 # 10 results for "powered by iScripts ReserveLogic" @ 2010-07-11
-examples %w|
-jamaicaoceanviewvilla.com/reservelogic/
-pigeonforgenow.com
-www.iguanalist.com
-hotelsaim.in
-stjohnvacationrentals.net/reservations/
-|
+
+# Dorks #
+dorks [
+'"powered by iScripts ReserveLogic"'
+]
+
+
 
 matches [
 
