@@ -13,15 +13,13 @@ version "0.2"
 description "Loggix is a really simple, lightweight PHP and SQlite driven weblog/cms engine. - homepage: http://loggix.gotdns.org/"
 
 # 22 results for "Powered by Loggix" @ 2010-06-15
-examples %w|
-loggix.gotdns.org
-jamlog.podzone.org
-quatrefoil.net/tale/
-d85.jp
-monolog.devgiri.org
-hbkt.scrapping.cc
-blog.apoderus.net
-|
+
+# Dorks #
+dorks [
+'"Powered by Loggix"'
+]
+
+
 
 matches [
 
