@@ -15,29 +15,15 @@ description "micro_httpd is a very small Unix-based HTTP server. It runs from in
 # ShodanHQ results as at 2010-10-26 #
 # 957,229 for "server: micro_httpd"
 
-# Examples #
-examples %w|
-78.162.53.58
-197.224.112.230
-183.89.22.130
-97.75.128.112
-190.98.45.133
-41.140.25.69
-94.43.137.3
-190.95.122.49
-89.249.219.51
-|
 
-# Passive #
-def passive
-	m=[]
 
-	# HTTP Server Header
-	m << { :name=>"HTTP Server Header" } if @meta["server"].to_s =~ /^[\s]*micro_httpd/i
+# Matches #
+matches [
 
-	# Return passive matches
-	m
-end
+# HTTP Server Header
+{ :search=>"headers[server]", :regexp=>/micro_httpd/i },
+
+]
 
 end
 
