@@ -11,11 +11,11 @@ author "Caleb Anderson"
 version "0.1"
 description "openid detection"
 
-examples %w|adrianlamologs.blogspot.com hackersinpinkdresses.wordpress.com|
+
 
 matches [
 {:name=>"openid",
-:regexp=>/<link .*?rel=['"](openid\.server|openid.delegate)['"].*?>/i
+:regexp=>/<link [^>]*rel=['"](openid\.server|openid\.delegate)['"][^>]*>/i
 },
 
 ]
