@@ -10,16 +10,13 @@ version "0.1"
 description "homepage: http://phpmesfilms.dyndns.org/"
 
 # 21 results for "powered by PhpMesFilms" @ 2001-08-21
-examples %w|
-phpmesfilms.dyndns.org/demo/admin/
-www.zikadonf.net/association/bibliotheque/admin/
-admin.domus.free.fr/video/
-karabos.net/perso/phpmesfilms/
-www.winmac-helper.net/phpmesfilms/
-video.memotek.com
-q2sac.free.fr/phpmesfilms_1.6/
-rapin.gregory.free.fr/MesFilms/
-|
+
+# Dorks #
+dorks [
+'"powered by PhpMesFilms"'
+]
+
+
 
 matches [
 
