@@ -10,38 +10,13 @@ version "0.1"
 description "Pressflow is a distribution of Drupal with integrated performance, scalability, availability, and testing enhancements. - homepage: http://pressflow.org/"
 
 # 67 results for +"powered by Pressflow" +"an open source content management system" @ 2010-07-18
-examples %w|
-patprzybilla.me
-gotdrupal.com/videos/
-newleafdigital.com
-www.orved.org
-agtoday.info
-api.lullabot.com
-deglos.com
-www.dogolympicgames.eu
-nnewton.org
-www.ronnbot.com
-davidseth.net
-www.outlandishjosh.com/blogs/
-frequencygrease.com
-openlearninglabs.org
-www.universalizer.com
-webkenny.com
-www.stealthip.com
-www.caktux.ca/blog/
-www.ecoforestry.ca
-www.ontogrator.com
-www.2tmsviluppo.com/pressflow/
-zoraweb.com
-joestewartjr.com
-www.613commandments.com
-drupalwebdesign.com.au
-www.mascellaro.it
-drupaldanmark.dk
-www.widescreenbabes.com
-www.fastdrupalthemes.com/install.php
-osuosl.org/install.php
-|
+
+# Dorks #
+dorks [
+'"powered by Pressflow" "an open source content management system"'
+]
+
+
 
 matches [
 
