@@ -10,20 +10,7 @@ version "0.1"
 description "PHP powered Shopping cart - homepage: http://www.source-worx.de/"
 
 # 24 results for "powered by sX-Shop" -inurl -Vulnerabilities -Vulnerability @ 2010-10-14
-examples %w|
-top-brille.com
-www.arte-natura.ch/shop/
-www.artenatura.ch
-www.autoteilebedarf.de/shop/
-www.cycletec.de/shop/
-www.demo-shopsystem.de/shop/
-www.eisen-kiessling.de
-www.foto-lippka.de/shop/
-www.masaadvertising.de/shop/
-www.photo-lippka.de/shop/shop/
-www.stickprint.de
-www.topbrille.com/shop/
-|
+
 
 matches [
 
