@@ -10,14 +10,13 @@ version "0.1"
 description "SmodCMS - homepage: http://www.smod.pl/"
 
 # 13 results for "powered by SmodCMS" @ 2010-08-16
-examples %w|
-www.szkolakorlino.pl
-jaroslawiec24.com
-nowy.poznan.kph.org.pl
-www.mariuszgorczynski.pl
-www.travelneo.pl
-poznan.kph.org.pl
-|
+
+# Dorks #
+dorks [
+'"powered by SmodCMS"'
+]
+
+
 
 matches [
 
