@@ -15,21 +15,12 @@ description "XHP CMS - eXpandable Home Page is an easy to install, easy to use,
 # Google results as at 2010-08-08 #
 # 22 for "powered by XHP CMS" "Site engine is copyright"
 
-# Examples #
-examples %w|
-xhp.targetit.ro
-eclipse-sdcc.sourceforge.net
-royal-african-stone.com/XHP/
-www.validtradeantiques.co.za
-www.boorysbusinessmachines.com
-bytepoker.com
-www.dwmchan.com/xhp/
-www.mitfun.ro
-ecu.gt28.ru
-sarberki-minerva.hu
-darkrula.net46.net
-www.nicolai.jellevedel.dk
-|
+# Dorks #
+dorks [
+'"powered by XHP CMS" "Site engine is copyright"'
+]
+
+
 
 # Matches #
 matches [
