@@ -15,20 +15,12 @@ description "Control every facet of your store, from merchandising to promotions
 # Google results as at 2010-08-06 #
 # 43 for "powered by ZeusCart"
 
-# Examples #
-examples %w|
-points-goo.com
-pc1source.net
-www.natural-health-direct.co.uk/admin/
-ajdemos.com/demo/zeuscart/v3/
-indyabuy.com
-sleep-supply.com
-www.brandonraynor.com/onlinestore/
-a9e9.com/store/
-rhea-lr.com
-pctintas.net
-goldglob.com
-|
+# Dorks #
+dorks [
+'"powered by ZeusCart"'
+]
+
+
 
 # Matches #
 matches [
